@@ -6,20 +6,20 @@ isort:skip_file
 # flake8: NOQA: E402
 
 # -- stdlib imports ------------------------------------------------------------
+from parfive import __version__
 import datetime
 from packaging.version import Version
 
 # -- Project information -------------------------------------------------------
 
-project = 'Parfive'
-author = 'Stuart Mumford and Contributors'
-copyright = '{}, {}'.format(datetime.datetime.now().year, author)
+project = "Parfive"
+author = "Stuart Mumford and Contributors"
+copyright = "{}, {}".format(datetime.datetime.now().year, author)
 
 # The full version, including alpha/beta/rc tags
-from parfive import __version__
 release = __version__
 parfive_version = Version(__version__)
-is_release = not(parfive_version.is_prerelease or parfive_version.is_devrelease)
+is_release = not (parfive_version.is_prerelease or parfive_version.is_devrelease)
 
 # -- General configuration -----------------------------------------------------
 
@@ -27,17 +27,19 @@ is_release = not(parfive_version.is_prerelease or parfive_version.is_devrelease)
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
 # ones.
 extensions = [
-    'sphinx.ext.autodoc',
-    'sphinx.ext.coverage',
-    'sphinx.ext.doctest',
-    'sphinx.ext.inheritance_diagram',
-    'sphinx.ext.intersphinx',
-    'sphinx.ext.mathjax',
-    'sphinx.ext.napoleon',
-    'sphinx.ext.todo',
-    'sphinx.ext.viewcode',
-    'sphinx_automodapi.automodapi',
-    'sphinx_automodapi.smart_resolver',
+    "sphinx.ext.autodoc",
+    "sphinx.ext.coverage",
+    "sphinx.ext.doctest",
+    "sphinx.ext.inheritance_diagram",
+    "sphinx.ext.intersphinx",
+    "sphinx.ext.mathjax",
+    "sphinx.ext.napoleon",
+    "sphinx.ext.todo",
+    "sphinx.ext.viewcode",
+    "sphinx_autodoc_typehints",  # must be loaded after napoleon
+    "sphinx_automodapi.automodapi",
+    "sphinx_automodapi.smart_resolver",
+    "sphinx_contributors",
 ]
 
 # Add any paths that contain templates here, relative to this directory.
@@ -50,20 +52,20 @@ extensions = [
 # Add any extra paths that contain custom files (such as robots.txt or
 # .htaccess) here, relative to this directory. These files are copied
 # directly to the root of the documentation.
-html_extra_path = ['robots.txt']
+html_extra_path = ["robots.txt"]
 
-exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']
+exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]
 
 # The suffix(es) of source filenames.
 # You can specify multiple suffix as a list of string:
-source_suffix = '.rst'
+source_suffix = ".rst"
 
 # The master toctree document.
-master_doc = 'index'
+master_doc = "index"
 
 # The reST default role (used for this markup: `text`) to use for all
 # documents. Set to the "smart" one.
-default_role = 'obj'
+default_role = "obj"
 
 # Disable having a separate return type row
 napoleon_use_rtype = False
@@ -71,42 +73,50 @@ napoleon_use_rtype = False
 # Disable google style docstrings
 napoleon_google_docstring = False
 
+# Type Hint Config
+typehints_fully_qualified = False
+typehints_use_rtype = napoleon_use_rtype
+typehints_defaults = "comma"
+
 # -- Options for intersphinx extension -----------------------------------------
 
 # Example configuration for intersphinx: refer to the Python standard library.
-intersphinx_mapping = {'https://docs.python.org/': None,
-                       'http://aiohttp.readthedocs.io/en/stable': None,
-                       'https://aioftp.readthedocs.io/': None}
+intersphinx_mapping = {
+    "https://docs.python.org/": None,
+    "https://docs.aiohttp.org/en/stable": None,
+    "https://aioftp.readthedocs.io/": None,
+}
 
 # -- Options for HTML output ---------------------------------------------------
 
 # The theme to use for HTML and HTML Help pages.  See the documentation for
 # a list of builtin themes.
+html_theme = "sphinx_book_theme"
 
-try:
-    from sunpy_sphinx_theme.conf import *  # NOQA
-
-    html_theme_options = {
-        'logo_url': 'https://parfive.readthedocs.io/en/latest/',
-        "page_toctree_depths": {}
-    }
-
-except ImportError:
-    pass
+html_theme_options = {
+    "home_page_in_toc": True,
+    "repository_url": "https://github.com/Cadair/parfive",
+    "use_repository_button": True,
+    "use_issues_button": True,
+    "use_download_button": False,
+}
 
 # Add any paths that contain custom static files (such as style sheets) here,
 # relative to this directory. They are copied after the builtin static files,
 # so a file named "default.css" will overwrite the builtin "default.css".
-# html_static_path = ['_static']
+html_static_path = ["static"]
+html_css_files = [
+    "css/contributors.css",
+]
 
 # Render inheritance diagrams in SVG
 graphviz_output_format = "svg"
 
 graphviz_dot_args = [
-    '-Nfontsize=10',
-    '-Nfontname=Helvetica Neue, Helvetica, Arial, sans-serif',
-    '-Efontsize=10',
-    '-Efontname=Helvetica Neue, Helvetica, Arial, sans-serif',
-    '-Gfontsize=10',
-    '-Gfontname=Helvetica Neue, Helvetica, Arial, sans-serif'
+    "-Nfontsize=10",
+    "-Nfontname=Helvetica Neue, Helvetica, Arial, sans-serif",
+    "-Efontsize=10",
+    "-Efontname=Helvetica Neue, Helvetica, Arial, sans-serif",
+    "-Gfontsize=10",
+    "-Gfontname=Helvetica Neue, Helvetica, Arial, sans-serif",
 ]
