@@ -1,21 +1,19 @@
 import os
-import sys
 import platform
 from pathlib import Path
 from unittest import mock
-from importlib import reload
 from unittest.mock import patch
 
 import aiohttp
 import pytest
 from aiohttp import ClientTimeout
-from pytest_localserver.http import WSGIServer
 
 import parfive
+from parfive.config import SessionConfig
 from parfive.downloader import Downloader, FailedDownload, Results, Token
 from parfive.utils import sha256sum
 
-skip_windows = pytest.mark.skipif(platform.system() == 'Windows', reason="Windows.")
+skip_windows = pytest.mark.skipif(platform.system() == "Windows", reason="Windows.")
 
 
 def validate_test_file(f):
@@ -36,8 +34,9 @@ def test_setup():
 
 def test_download(httpserver, tmpdir):
     tmpdir = str(tmpdir)
-    httpserver.serve_content('SIMPLE  = T',
-                             headers={'Content-Disposition': "attachment; filename=testfile.fits"})
+    httpserver.serve_content(
+        "SIMPLE  = T", headers={"Content-Disposition": "attachment; filename=testfile.fits"}
+    )
     dl = Downloader()
 
     dl.enqueue_file(httpserver.url, path=Path(tmpdir), max_splits=None)
@@ -50,8 +49,9 @@ def test_download(httpserver, tmpdir):
 
 def test_simple_download(httpserver, tmpdir):
     tmpdir = str(tmpdir)
-    httpserver.serve_content('SIMPLE  = T',
-                             headers={'Content-Disposition': "attachment; filename=testfile.fits"})
+    httpserver.serve_content(
+        "SIMPLE  = T", headers={"Content-Disposition": "attachment; filename=testfile.fits"}
+    )
 
     f = Downloader.simple_download([httpserver.url], path=Path(tmpdir))
     validate_test_file(f)
@@ -60,8 +60,9 @@ def test_simple_download(httpserver, tmpdir):
 def test_changed_max_conn(httpserver, tmpdir):
     # Check that changing max_conn works after creating Downloader
     tmpdir = str(tmpdir)
-    httpserver.serve_content('SIMPLE  = T',
-                             headers={'Content-Disposition': "attachment; filename=testfile.fits"})
+    httpserver.serve_content(
+        "SIMPLE  = T", headers={"Content-Disposition": "attachment; filename=testfile.fits"}
+    )
     dl = Downloader(max_conn=4)
     dl.enqueue_file(httpserver.url, path=Path(tmpdir), max_splits=None)
     dl.max_conn = 3
@@ -73,9 +74,10 @@ def test_changed_max_conn(httpserver, tmpdir):
 @pytest.mark.asyncio
 @pytest.mark.parametrize("use_aiofiles", [True, False])
 async def test_async_download(httpserver, tmpdir, use_aiofiles):
-    httpserver.serve_content('SIMPLE  = T',
-                             headers={'Content-Disposition': "attachment; filename=testfile.fits"})
-    dl = Downloader(use_aiofiles=use_aiofiles)
+    httpserver.serve_content(
+        "SIMPLE  = T", headers={"Content-Disposition": "attachment; filename=testfile.fits"}
+    )
+    dl = Downloader(config=SessionConfig(use_aiofiles=use_aiofiles))
 
     dl.enqueue_file(httpserver.url, path=Path(tmpdir), max_splits=None)
 
@@ -87,8 +89,9 @@ async def test_async_download(httpserver, tmpdir, use_aiofiles):
 
 def test_download_ranged_http(httpserver, tmpdir):
     tmpdir = str(tmpdir)
-    httpserver.serve_content('SIMPLE  = T',
-                             headers={'Content-Disposition': "attachment; filename=testfile.fits"})
+    httpserver.serve_content(
+        "SIMPLE  = T", headers={"Content-Disposition": "attachment; filename=testfile.fits"}
+    )
     dl = Downloader()
 
     dl.enqueue_file(httpserver.url, path=Path(tmpdir))
@@ -101,9 +104,13 @@ def test_download_ranged_http(httpserver, tmpdir):
 
 def test_regression_download_ranged_http(httpserver, tmpdir):
     tmpdir = str(tmpdir)
-    httpserver.serve_content('S',
-                             headers={'Content-Disposition': "attachment; filename=testfile.fits",
-                                      'Accept-Ranges': "bytes"})
+    httpserver.serve_content(
+        "S",
+        headers={
+            "Content-Disposition": "attachment; filename=testfile.fits",
+            "Accept-Ranges": "bytes",
+        },
+    )
     dl = Downloader()
 
     dl.enqueue_file(httpserver.url, path=Path(tmpdir))
@@ -116,7 +123,7 @@ def test_regression_download_ranged_http(httpserver, tmpdir):
 
 def test_download_partial(httpserver, tmpdir):
     tmpdir = str(tmpdir)
-    httpserver.serve_content('SIMPLE  = T')
+    httpserver.serve_content("SIMPLE  = T")
     dl = Downloader()
 
     dl.enqueue_file(httpserver.url, filename=lambda resp, url: Path(tmpdir) / "filename")
@@ -135,7 +142,7 @@ def test_empty_download(tmpdir):
 
 
 def test_download_filename(httpserver, tmpdir):
-    httpserver.serve_content('SIMPLE  = T')
+    httpserver.serve_content("SIMPLE  = T")
 
     fname = "testing123"
     filename = str(tmpdir.join(fname))
@@ -154,7 +161,7 @@ def test_download_filename(httpserver, tmpdir):
 
 
 def test_download_no_overwrite(httpserver, tmpdir):
-    httpserver.serve_content('SIMPLE  = T')
+    httpserver.serve_content("SIMPLE  = T")
 
     fname = "testing123"
     filename = str(tmpdir.join(fname))
@@ -178,7 +185,7 @@ def test_download_no_overwrite(httpserver, tmpdir):
 
 
 def test_download_overwrite(httpserver, tmpdir):
-    httpserver.serve_content('SIMPLE  = T')
+    httpserver.serve_content("SIMPLE  = T")
 
     fname = "testing123"
     filename = str(tmpdir.join(fname))
@@ -200,14 +207,14 @@ def test_download_overwrite(httpserver, tmpdir):
 
 
 def test_download_unique(httpserver, tmpdir):
-    httpserver.serve_content('SIMPLE  = T')
+    httpserver.serve_content("SIMPLE  = T")
 
     fname = "testing123"
     filename = str(tmpdir.join(fname))
 
-    filenames = [filename, filename + '.fits', filename + '.fits.gz']
+    filenames = [filename, filename + ".fits", filename + ".fits.gz"]
 
-    dl = Downloader(overwrite='unique')
+    dl = Downloader(overwrite="unique")
 
     # Write files to both the target filenames.
     for fn in filenames:
@@ -226,38 +233,6 @@ def test_download_unique(httpserver, tmpdir):
         assert f"{fname}.1" in fn
 
 
-@pytest.fixture
-def testserver(request):
-    """
-    A server that throws a 404 for the second request.
-    """
-    counter = 0
-
-    def simple_app(environ, start_response):
-        """
-        Simplest possible WSGI application.
-        """
-        nonlocal counter
-
-        counter += 1
-        if counter != 2:
-            status = '200 OK'
-            response_headers = [('Content-type', 'text/plain'),
-                                ('Content-Disposition', (f'testfile_{counter}'))]
-            start_response(status, response_headers)
-            return [b'Hello world!\n']
-        else:
-            status = '404'
-            response_headers = [('Content-type', 'text/plain')]
-            start_response(status, response_headers)
-            return ""
-
-    server = WSGIServer(application=simple_app)
-    server.start()
-    request.addfinalizer(server.stop)
-    return server
-
-
 def test_retrieve_some_content(testserver, tmpdir):
     """
     Test that the downloader handles errors properly.
@@ -277,7 +252,7 @@ def test_retrieve_some_content(testserver, tmpdir):
 
 def test_no_progress(httpserver, tmpdir, capsys):
     tmpdir = str(tmpdir)
-    httpserver.serve_content('SIMPLE  = T')
+    httpserver.serve_content("SIMPLE  = T")
     dl = Downloader(progress=False)
 
     dl.enqueue_file(httpserver.url, path=tmpdir)
@@ -296,7 +271,7 @@ def throwerror(*args, **kwargs):
 @patch("parfive.downloader.default_name", throwerror)
 def test_raises_other_exception(httpserver, tmpdir):
     tmpdir = str(tmpdir)
-    httpserver.serve_content('SIMPLE  = T')
+    httpserver.serve_content("SIMPLE  = T")
     dl = Downloader()
 
     dl.enqueue_file(httpserver.url, path=tmpdir)
@@ -394,7 +369,10 @@ def test_ftp_pasv_command(tmpdir):
     tmpdir = str(tmpdir)
     dl = Downloader()
     dl.enqueue_file(
-        "ftp://ftp.ngdc.noaa.gov/STP/swpc_products/daily_reports/solar_region_summaries/2002/04/20020414SRS.txt", path=tmpdir, passive_commands=["pasv"])
+        "ftp://ftp.ngdc.noaa.gov/STP/swpc_products/daily_reports/solar_region_summaries/2002/04/20020414SRS.txt",
+        path=tmpdir,
+        passive_commands=["pasv"],
+    )
     assert dl.queued_downloads == 1
     f = dl.download()
     assert len(f) == 1
@@ -405,7 +383,7 @@ def test_ftp_pasv_command(tmpdir):
 @pytest.mark.allow_hosts(True)
 def test_ftp_http(tmpdir, httpserver):
     tmpdir = str(tmpdir)
-    httpserver.serve_content('SIMPLE  = T')
+    httpserver.serve_content("SIMPLE  = T")
     dl = Downloader()
 
     dl.enqueue_file("ftp://ftp.swpc.noaa.gov/pub/warehouse/2011/2011_SRS.tar.gz", path=tmpdir)
@@ -424,8 +402,9 @@ def test_ftp_http(tmpdir, httpserver):
 
 def test_default_user_agent(httpserver, tmpdir):
     tmpdir = str(tmpdir)
-    httpserver.serve_content('SIMPLE  = T',
-                             headers={'Content-Disposition': "attachment; filename=testfile.fits"})
+    httpserver.serve_content(
+        "SIMPLE  = T", headers={"Content-Disposition": "attachment; filename=testfile.fits"}
+    )
 
     dl = Downloader()
     dl.enqueue_file(httpserver.url, path=Path(tmpdir), max_splits=None)
@@ -434,36 +413,41 @@ def test_default_user_agent(httpserver, tmpdir):
 
     dl.download()
 
-    assert 'User-Agent' in httpserver.requests[0].headers
-    assert httpserver.requests[0].headers[
-        'User-Agent'] == f"parfive/{parfive.__version__} aiohttp/{aiohttp.__version__} python/{sys.version[:5]}"
+    assert "User-Agent" in httpserver.requests[0].headers
+    assert (
+        httpserver.requests[0].headers["User-Agent"]
+        == f"parfive/{parfive.__version__} aiohttp/{aiohttp.__version__} python/{platform.python_version()}"
+    )
 
 
 def test_custom_user_agent(httpserver, tmpdir):
     tmpdir = str(tmpdir)
-    httpserver.serve_content('SIMPLE  = T',
-                             headers={'Content-Disposition': "attachment; filename=testfile.fits"})
+    httpserver.serve_content(
+        "SIMPLE  = T", headers={"Content-Disposition": "attachment; filename=testfile.fits"}
+    )
 
-    dl = Downloader(headers={'User-Agent': 'test value 299792458'})
+    dl = Downloader(config=SessionConfig(headers={"User-Agent": "test value 299792458"}))
     dl.enqueue_file(httpserver.url, path=Path(tmpdir), max_splits=None)
 
     assert dl.queued_downloads == 1
 
     dl.download()
 
-    assert 'User-Agent' in httpserver.requests[0].headers
-    assert httpserver.requests[0].headers['User-Agent'] == "test value 299792458"
+    assert "User-Agent" in httpserver.requests[0].headers
+    assert httpserver.requests[0].headers["User-Agent"] == "test value 299792458"
 
 
-@patch.dict(os.environ, {'HTTP_PROXY': "http_proxy_url", 'HTTPS_PROXY': "https_proxy_url"})
-@pytest.mark.parametrize("url,proxy", [('http://test.example.com',
-                                        'http_proxy_url'), ('https://test.example.com', 'https_proxy_url')])
+@patch.dict(os.environ, {"HTTP_PROXY": "http_proxy_url", "HTTPS_PROXY": "https_proxy_url"})
+@pytest.mark.parametrize(
+    "url,proxy",
+    [
+        ("http://test.example.com", "http_proxy_url"),
+        ("https://test.example.com", "https_proxy_url"),
+    ],
+)
 def test_proxy_passed_as_kwargs_to_get(tmpdir, url, proxy):
 
-    with mock.patch(
-        "aiohttp.client.ClientSession._request",
-        new_callable=mock.MagicMock
-    ) as patched:
+    with mock.patch("aiohttp.client.ClientSession._request", new_callable=mock.MagicMock) as patched:
 
         dl = Downloader()
         dl.enqueue_file(url, path=Path(tmpdir), max_splits=None)
@@ -473,36 +457,11 @@ def test_proxy_passed_as_kwargs_to_get(tmpdir, url, proxy):
         dl.download()
 
     assert patched.called, "`ClientSession._request` not called"
-    assert list(patched.call_args) == [('GET', url),
-                                       {'allow_redirects': True,
-                                        'timeout': ClientTimeout(total=0, connect=None, sock_read=90, sock_connect=None),
-                                        'proxy': proxy
-                                        }]
-
-
-@pytest.mark.parametrize("use_aiofiles", [True, False])
-def test_enable_aiofiles_constructor(use_aiofiles):
-    dl = Downloader(use_aiofiles=use_aiofiles)
-    assert dl.use_aiofiles == use_aiofiles, f"expected={dl.use_aiofiles}, got={use_aiofiles}"
-
-
-@patch.dict(os.environ, {'PARFIVE_OVERWRITE_ENABLE_AIOFILES': "some_value_to_enable_it"})
-@pytest.mark.parametrize("use_aiofiles", [True, False])
-def test_enable_aiofiles_env_overwrite_always_enabled(use_aiofiles):
-    dl = Downloader(use_aiofiles=use_aiofiles)
-    assert dl.use_aiofiles is True
-
-
-@pytest.fixture
-def remove_aiofiles():
-    parfive.downloader.aiofiles = None
-    yield
-    reload(parfive.downloader)
-
-
-@pytest.mark.parametrize("use_aiofiles", [True, False])
-def test_enable_no_aiofiles(remove_aiofiles, use_aiofiles):
-    Downloader.use_aiofiles.fget.cache_clear()
-
-    dl = Downloader(use_aiofiles=use_aiofiles)
-    assert dl.use_aiofiles is False
+    assert list(patched.call_args) == [
+        ("GET", url),
+        {
+            "allow_redirects": True,
+            "timeout": ClientTimeout(total=0, connect=None, sock_read=90, sock_connect=None),
+            "proxy": proxy,
+        },
+    ]
